@@ -54,6 +54,15 @@ use base 'RT::SearchBuilder';
 
 sub Table {'Classes'}
 
+=head2 _Init
+
+=cut
+
+ sub _Init {
+    my $self = shift;
+    $self->{'with_disabled_column'} = 1;
+    return ($self->SUPER::_Init(@_));
+ }
 
 =head2 Next
 
